<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kópia z</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Každý %1 ťah</numerusform>
            <numerusform>Každé %1 ťahy</numerusform>
            <numerusform>Každých %1 ťahov</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Upraviť zbrane</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Neplatná schéma zbraní</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Upraviť schémy</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon (and viceversa)</source>
        <translation type="obsolete">Ak je táto voľba vybraná, zvolením hernej schémy budú automaticky vybrané aj zbrane (a naopak)</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>Keď je vybraná táto voľba výberom hernej schémy vyberiete automaticky aj zbraň</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu priateľov</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu priateľov</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Nie je možné spustiť server</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nie je možné zapísať záznam do súboru %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">nový</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Prosím vyberte záznam zo zoznamu vyššie</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>VýchodzíTím</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Demo súbor Hedgewars</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Súbor s uloženou hrou Hedgewars</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>sk.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Nie je možné otvoriť demosúbor %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Všetky</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Malá</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Stredná</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Veľká</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Jaskyňa</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Pojašená</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Malé tunely</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Stredné tunely</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Veľké tunely</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Malé plávajúce ostrovčeky</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Stredné plávajúce ostrovčeky</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Veľké plávajúce ostrovčeky</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>Zrno</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished">Nastaviť</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Hostiteľ nebol nájdený. Prosím, skontrolujte názov hostiteľa a nastavenia portu.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Spojenie odmietnuté</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Dôvod odchodu: </translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Miestnosť zrušená</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Boli ste vykopnutý</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">Vaša prezývka %1 je
zaregistrovaná na Hedgewars.org
Prosím, zadajte heslo alebo
si vyberte inú prezývku:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 prišiel do miestnosti</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 sa pridal</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 odišiel (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 odišiel</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>Prezývka %1, ktorú ste
si vybrali je registrovaná na
Hedgewars.org.
Prosím, napíšte heslo do poľa
nižšie alebo si zvoľte inú prezývku
v nastaveniach hry:</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf vrátil chybu počas renderovania textu, s najväčšou pravdepodobnosťou sa jedná o chybu vo freetype2. Doporučujeme aktualizovať vašu knižnicu freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Správa serveru:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Nastaviť správu</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Vymazať vyrovnávaciu pamäť účtov</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Stiahnuť dáta</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Správa serveru pre najnovšiu verziu:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Správa serveru pre prechádzajúce verzie:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Najnovšia verzia protokolu:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Náhľad správy dňa (MOTD):</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Nastaviť dáta</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Pripájam sa...</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>Odvolať</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Načítať</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>Načítať nakreslenú mapu</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation>Nakreslené mapy (*.hwmap);;Všetky súbory (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>Uložiť nakreslenú mapu</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Ocenenie za najlepší zásah vyhral(a) &lt;b&gt;%1&lt;/b&gt; so ziskom &lt;b&gt;%2&lt;/b&gt; bodov.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;jedným&lt;/b&gt; zabitím počas ťahu.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Celkovo bol v tomto kole zabitý &lt;b&gt;jeden&lt;/b&gt; ježko.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Vývoj zdravia</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Rebríček</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>Ocenenie za najlepší zásah vyhral(a) &lt;b&gt;%1&lt;/b&gt; so ziskom &lt;b&gt;%2&lt;/b&gt; bodov.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;jedným&lt;/b&gt; zabitím počas ťahu.</numerusform>
            <numerusform>Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.</numerusform>
            <numerusform>Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Celkovo bol v tomto kole zabitý &lt;b&gt;%1&lt;/b&gt; ježko.</numerusform>
            <numerusform>Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.</numerusform>
            <numerusform>Celkovo bol v tomto kole zabitých &lt;b&gt;%1&lt;/b&gt; ježkov.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 zabitie)</numerusform>
            <numerusform>(%1 zabitia)</numerusform>
            <numerusform>(%1 zabití)</numerusform>
        </translation>
    </message>
    <message>
        <source>(%1 kills)</source>
        <translation type="obsolete">(%1 zabití)</translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa nazdával, že je vhodné strieľať po svojich a získal tak &lt;b&gt;%2&lt;/b&gt; bod.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa nazdával, že je vhodné strieľať po svojich a získal tak &lt;b&gt;%2&lt;/b&gt; body.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa nazdával, že je vhodné strieľať po svojich a získal tak &lt;b&gt;%2&lt;/b&gt; bodov.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; svojho druha.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; svojich druhov.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; zabil &lt;b&gt;%2&lt;/b&gt; svojich druhov.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa zľakol a preskočil ťah &lt;b&gt;%2&lt;/b&gt;krát.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa zľakol a preskočil ťah &lt;b&gt;%2&lt;/b&gt;krát.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; sa zľakol a preskočil ťah &lt;b&gt;%2&lt;/b&gt;krát.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Miestna hra (Hrať hru proti počítaču)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Sieťová hra (Hrať hru proti súperom na sieti)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Ak chcete hrať s priateľom ako tím, jednoducho si zvoľte tú istú farbu. I naďalej budete ovládať svojich vlastných ježkov, ale víťazstvá či prehry budú spoločné.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Niektoré zbrane môžu spôsobovať málo škody, ale dokážu byť oveľa účinnejšie v tej správnej situácii. Skúste použiť Desert Eagle na zostrelenie viacerých ježkov do vody.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Ak neviete, čo robiť a nechcete mrhať muníciou, preskočte ťah. Ale nerobte tak príliš často, pretože príde Náhla smrť!</translation>
    </message>
    <message>
        <source>Want to save ropse? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="obsolete">Chcete ušetriť lano? Kým ste vo vzduchu, uvoľnite ho a opäť vystreľte. Kým sa nedotknete zeme, môžete to isté lano znovu použiť bez toho, aby sa vám míňali jeho zásoby!</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Ak nechcete, aby niekto iný používal vašu prezývku na oficiálnom serveri, registrujte si účet na http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>Nudí vás štandardná hra? Vyskúšajte si jednu z misii - ponúkajú iný herný zážitok v závislosti na tom, akú si vyberiete.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>Vo východzom nastavení sa posledná hra automaticky ukladá ako demo. Vyberte &apos;Miestna hra&apos; a kliknite na tlačidlo &apos;Demá&apos; v pravom dolnom rohu, ak si chcete demo uložiť alebo prehrať.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, ktorý vytvárame vo voľnom čase. Ak máte problém, spýtajte sa na fóre, ale nečakajte podporu 24 hodín v týždni!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, ktorý vytvárame vo voľnom čase. Ak chcete pomôcť, môžete nám zaslať malú finančnú výpomoc alebo prispieť vlastnou prácou!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, ktorý vytvárame vo voľnom čase. Podeľte sa oň so svojou rodinou a priateľmi!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>Z času na čas bývajú usporiadavané oficiálne turnaje. Najbližšie akcie sú vždy uverejnené na http://www.hedgewars.org/ pár dní dopredu.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je dostupný v mnohých jazykoch. Ak preklad do vašej reči chýba alebo nie je aktuálny, prosím, kontaktujte nás!</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>Hedgewars beží na množstve rozličných operačných systémov vrátane Microsoft Windows, Mac OS X a Linuxu.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Nezabudnite, že si vždy môžete vytvoriť vlastnú lokálnu alebo sieťovú/online hru. Nie ste obmedzený len na voľbu &apos;Jednoduchá hra&apos;.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>Mali by ste si dopriať krátky odpočinok po každej hodine hry.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Ak vaša grafická karta nie je schopná poskytnúť hardvérovo akcelerované OpenGL, skúste povoliť režim nízkej kvality, aby ste dosiahli požadovaný výkon.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Sme otvorení novým nápadom a konštruktívnej kritike. Ak sa vám niečo nepáči alebo máte skvelý nápad, dajte nám vedieť!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Obzvlášť pri hre online buďte slušný a pamätajte, že s vami alebo proti vám môžu hrať tiež neplnoletí!</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Špeciálne herné režimy ako &apos;Vampírizmus&apos; alebo &apos;Karma&apos; vám umožnia vyvinúť úplne novú taktiku. Vyskúšajte ich vo vlastnej hre!</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation>Verzia Hedgewars pre Windows podporuje Xfire. Ubezpečte sa, že ste pridali Hedgewars do zoznamu hier tak, aby vaši priatelia videli, že hráte.</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>Nikdy by ste nemali inštalovať Hedgewars na cudzí počítač (v škole, na univerzite, v práci, atď). Prosím, radšej požiadajte zodpovednú osobu!</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>Hedgewars môže byť výborná hra, ak máte krátku chvíľku počas prestávky. Iba sa uistite, že nepoužijete príliš veľa ježkov alebo príliš veľkú mapu. Rovnako môže pomocť zníženie času a zdravia.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Počas tvorby tejto hry nebolo ublížené žiadnemu ježkovi.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>Hedgewars je Open Source a Freeware, ktorý vytvárame vo voľnom čase. Ak vám niekto túto hru predal, skúste žiadať o refundáciu!</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Ak chcete pre hru použiť jeden alebo viacero gamepadov, pripojte ich pred spustením hry.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Vytvorte si účet na %1, aby ste tak zabránili ostatným používať vašu obľúbenú prezývku počas hrania na oficiálnom serveri.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Ak vaša grafická karta nie je schopná poskytnúť hardvérovo akcelerované OpenGL, skúste aktualizovať príslušné ovládače.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>Dostupné sú tri rôzne výskoky. Dvakrát stlačte [vysoký skok] pre veľmi vysoký skok vzad.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>Bojíte sa pádu z útesu? Podržte [presné mierenie] a stlačte [doľava] alebo [doprava] pre otočenie na mieste.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Niektoré zbrane vyžaduju osobitnú stratégiu alebo len veľa tréningu, takže to s vybranou zbraňou nevzdávajte, ak sa vám nepodarí trafiť nepriateľa.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>Väčšina zbraní prestane fungovať pri kontakte s vodou. Navádzané včela a Torta sú výnimkami z tohto pravidla.</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>Starý cheeseburger spôsobí len malú explóziu. Obláčik smradu, ktorý je ovplyvňovaný vetrom, však dokáže otráviť množstvo ježkov.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>Klavírový útok je najzničujúcejší vzdušný útok. Pri jeho použití prídete o ježka, čo je jeho veľké mínus.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation>Navádzaná včela je trošku zložitejšia na použitie. Jej polomer otočenia závisí na jej rýchlosti, takže ju radšej nepoužívajte pri plnej sile.</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>Lepkavé míny sú perfektným nástrojom na vytvorenie malých reťazových reakcii, vďaka ktorým postavíte ježkov do krajných situácii ... alebo vody.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>Kladivo je najefektívnejšie pri použití na mostoch alebo trámoch. Zasiahnutí ježkovia prerazia zem.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Ak ste zaseknutý za nepriateľským ježkom, použite kladivo, aby ste sa oslobodili bez toho, aby vám ublížila explózia.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>Maximálna prejdená vzdialenosť torty zavisí na zemi, ktorou musí prejsť. Použitie [útok], ak chcete spustiť detonáciu skôr.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>Plameňomet je zbraň, no rovnako môže byť použitý na kopanie tunelov.</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation>Použite spaľujúci granát na dočasné zabránenie ježkom prejsť terénom ako sú tunely alebo plošiny.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>Chcete vedieť, kto stojí za hrou? Kliknite na logo Hedgewars v hlavnom menu pre zobrazenie zásluh.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or join our group at %2. You could follow us on %3 as well!</source>
        <comment>Tips</comment>
        <translation type="obsolete">Pačia sa vám Hedgewars? Staňte sa fanúšikom na %1 alebo sa pripojte k našej skupine na %2. Môžte nás tiež nasledovať na %3!</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>Ak máte chuť, môžte si nakresliť vlastné hrobčeky, klobúky, vlajky alebo dokonca mapy a témy! Pamätajte však, že ak ich budete chcieť použiť v hre online, budete ich musieť zdieľať s ostatnými.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>Chcete nosiť špecifický klobúk? Prispejte nám a ako odmenu získate exkluzívny klobúk podľa vášho výberu!</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Aby ste sa vyhli problémom pri hre, udržujte ovládače vašej grafickej karty vždy aktuálne.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Konfiguračné súbory Hedgewars nájdete v &quot;Moje Dokumenty\Hedgewars&quot;. Vytvárajte si zálohy alebo prenášajte si tieto súbory medzi počítačmi, ale needitujte ich ručne.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Konfiguračné súbory Hedgewars nájdete v &quot;Hedgewars&quot; vo vašom domovskom adresári. Vytvárajte si zálohy alebo prenášajte si tieto súbory medzi počítačmi, ale needitujte ich ručne.</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>Chcete ušetriť lano? Kým ste vo vzduchu, uvoľnite ho a opäť vystreľte. Kým sa nedotknete zeme, môžete to isté lano znovu použiť bez toho, aby sa vám míňali jeho zásoby!</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>Páčia sa vám Hedgewars? Staňte sa fanúšikom na %1 alebo sa pripojte k našej skupine na %2. Môžte nás tiež nasledovať na %3!</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>Môžte priradiť súbory patriace Hedgewars (uložené hry a nahrávky záznamov) ku hre, čím sa vám budú otvárať priamo z vášho obľubeného prehliadača súborov alebo internetu.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Konfiguračné súbory Hedgewars nájdete v &quot;Library/Application Support/Hedgewars&quot; vo vašom domovskom adresári. Vytvárajte si zálohy alebo prenášajte si tieto súbory medzi počítačmi, ale needitujte ich ručne.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Konfiguračné súbory Hedgewars nájdete v &quot;.hedgewars&quot; vo vašom domovskom adresári. Vytvárajte si zálohy alebo prenášajte si tieto súbory medzi počítačmi, ale needitujte ich ručne.</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Prosím vyberte server zo zoznamu vyššie</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Ovládanie</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>LAN hra</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Oficiálny server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nový tím</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Upraviť tím</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Vymazať tím</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Nová schéma pre zbrane</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Upraviť schému pre zbrane</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Vymazať schému pre zbrane</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Z výberu tímov nemôžete upravovať tímy. Vráťte sa do hlavného menu, odkiaľ môžete pridávať, upravovať alebo mazať tímy.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>Nová schéma</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>Upraviť schému</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>Vymazať schému</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>Nová sada zbraní</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>Upraviť sadu zbraní</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>Vymazať sadu zbraní</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Dialóg na zmenu mena</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Zadajte nový názov súboru:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Nemôžem premenovať na</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Nemôžem vymazať súbor</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Prosím vyberte záznam zo zoznamu</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Vytvoriť</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Pripojiť sa</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Vlastnosti pre admina</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Názov miestnosti:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Táto hra je v lobby.
Môžete sa pridať a začať hru akonáhle hra skončí.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Táto hra práve prebieha.
Môžete sa pridať a sledovať hru, ale ak chcete hrať budete musieť počkať na koniec hry.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 je hostiteľom. Može meniť nastavenia a spúšťať hru.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Náhodná mapa</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Hry môžu byť hrané na predvytvorených alebo náhodných mapách.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Schéma hry určuje všeobecné voľby ako napríklad Dĺžka kola, Režim rýchlej smrti alebo Vampírizmus.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Schémy hry určuje dostupné zbrane a množstvo výzbroje.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>K tejto miestnosti je pripojený jeden klient.</numerusform>
            <numerusform>K tejto miestnosti sú pripojení %1 klienti.</numerusform>
            <numerusform>K tejto miestnosti je pripojených %1 klientov.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>V tejto miestnosti je jeden hrajúci tím.</numerusform>
            <numerusform>V tejto miestnosti sú %1 hrajúce tímy.</numerusform>
            <numerusform>V tejto miestnosti je %1 hrajúcich tímov.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Prosím zadajte názov miestnosti</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Prosím vyberte miestnosť zo zoznamu</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Náhodné bludisko</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Pravidlá:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Zbrane:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varovanie</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>Hra, ku ktorej sa snažíte pripojiť, už začala.
Aj napriek tomu chcete vojsť do miestnosti?</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Povoliť náhodne rozmiestnené míny</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>K vášmu zdraviu sa priráta 80 % škody, ktorú spôsobíte</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Zdieľanie bolesti vašich protivníkov, zdieľanie ich poškodenia</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Vaši ježkovia sa nemôžu pohnúť, otestujte si vaše delostrelecké schopnosti</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Náhodné</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekúnd</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Ubráňte pevnosť a zničte nepriateľov, maximálne dve tímové farby!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Tímy začnú na opačných stranách terénu, maximálne dve tímové farby!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Krajina sa nedá zničiť!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Pridať nezničiteľný okraj okolo terénu</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Nižšia gravitácia</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Pomocné laserové zameriavanie</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Všetci ježkovia majú osobné silové pole</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Poradie hrania je náhodné miesto poradia hráčov v miestnosti.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Hra s Kráľom. Ak zomrie, vaša strana prehráva.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Pred začatím hry sa súperi striedajú v umiestňovaní ježkov.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Výzbroj je zdieľaná medzi všetkými tímami, ktoré majú tú istú farbu.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Zakázať trámy pri generovaní náhodných máp.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Pri generovaní náhodnej mapy vypnúť objekty v krajine.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>Počítač po smrti ožije.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>Všetci (žijúci) ježkovia sú plne obnovení na konci ťahu</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Útok nespôsobí ukončenie vášho ťahu.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>Zbrane sú na konci každého ťahu nastavené na hodnoty na začiatku.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>Každý ježko má vlastnú výzbroj. Nie je zdieľaná so zvyškom tímu.</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>Už sa viac nebudete musieť zaujímať o vietor.</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>Vietor bude ovplyvňovať takmer všetko.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Východzie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Jednoduchá hra (rýchla hra proti počítaču, s preddefinovanými nastaveniami)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multiplayer (hrať hru, pri ktorej sa striedate s hráčmi pri počítači alebo proti počítačovým tímom)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Tréningový režim (vylepšujte si svoje zručnosti v rade tréningových misií). VO VÝVOJI</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demá (prehrávanie natočených demonahrávok)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Načítať (načíta v minulosti uloženú hru)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>Režim kampane (...) VO VÝVOJI</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Vykopnúť</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Obmedziť pripojenia</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Obmedziť pripojenie k tímu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Zakázať</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Nasledovať</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovať</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Pridať priateľa</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Zrušiť ignorovanie</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Odstrániť priateľa</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Kontrolovať aktualizácie pri štarte</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Povoliť zvuky</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Zobrazovať FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Iný spôsob zobrazovania škody</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend na celú obrazovku</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Povoliť hudbu</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Pripojiť dátum a čas k súboru so záznamom</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Znížená kvalita</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Zobrazovať nápovedu pre zbrane</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Povoliť zvuky vo frontende</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Povoliť hudbu vo frontende</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Efekty vo frontende</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>vygenerovaná mapa...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Človek</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Východzie nastavenie)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>vygenerované bludisko..</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Misia</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Komunita</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Ľubovoľný</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>V lobby</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>Prebieha</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Východzie</translation>
    </message>
    <message>
        <source>Pro mode</source>
        <translation type="obsolete">Režim profesionálov</translation>
    </message>
    <message>
        <source>Shoppa</source>
        <translation type="obsolete">Nakupovanie</translation>
    </message>
    <message>
        <source>Basketball</source>
        <translation type="obsolete">Basketbal</translation>
    </message>
    <message>
        <source>Minefield</source>
        <translation type="obsolete">Mínové pole</translation>
    </message>
    <message>
        <source>Barrel mayhem</source>
        <translation type="obsolete">Vzbura sudov</translation>
    </message>
    <message>
        <source>Tunnel hogs</source>
        <translation type="obsolete">Tunelujúci ježkovia</translation>
    </message>
    <message>
        <source>Crazy</source>
        <translation type="obsolete">Šialené</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normálna</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>ručne kreslená mapa...</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Členovia tímu</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Nastavenia kláves</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Pevnosť</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Tímy</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Nastavenia zvuku/grafiky</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Zbrane</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Sieťová hra</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Hrajúce tímy</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Modifikátory hry</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Základné nastavenia</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Nastavenia tímu</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Rozličné</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>Schémy a zbrane</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Čas pre míny</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Míny</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Tento program je distribuovaný podľa podmienok GNU General Publice License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Vývojári:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafika:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Preklady:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Osobitné poďakovanie:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Výzbroj</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Hostiteľ:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlíšenie</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Limit FPS</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Sieťový nick</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Názov servera:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Port servera:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzia</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Zvuky:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Úvodná hlasitosť zvuku</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Schéma hry</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modifikátor poškodenia</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Čas na ťah</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Úvodné zdravie</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Časový limit pre rýchlu smrť</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Padanie krabíc</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Názov schémy:</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% falošných mín</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Meno</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Hrobček</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Vlajka</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hlasy</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Jazykové nastavenia</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Vyžaduje reštart hry</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="obsolete">Toto zostavenie SVN je &apos;stále-vo-vývoji&apos; a nemusí byť kompatibilné s inými verziami hry.
Niektoré vlastnosti nemusia fungovať alebo nemusia byť dokončené. Používajte na vlastné riziko!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Výbušniny</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Tip: </translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Toto zostavenie je &apos;stále-vo-vývoji&apos; a nemusí byť kompatibilné s inými verziami hry.
Niektoré vlastnosti nemusia fungovať alebo nemusia byť dokončené. Používajte na vlastné riziko!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalita</translation>
    </message>
    <message>
        <source>Bind schemes and weapons</source>
        <translation type="obsolete">Prepojiť schémy a zbrane</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Stúpanie vody počas rýchlej smrti</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Klesanie zdravia počas rýchlej smrti</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% lekárničiek</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Zdravie v bedniach</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% dĺžka lana</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation>Hra</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>beznázvu</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Spojenie so serverom bolo prerušené</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Nepodarilo sa otvoriť dátový adresár:
%1
Skontrolujte si vašu inštaláciu</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbrane</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Nie je možné upraviť východziu sadu zbraní</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Nie je možné vymazať východziu sadu zbraní</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Určite chcete vymazať túto sadu zbraní?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Nie je možné prepísať východziu sadu zbraní &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Všetky súborové asociácie boli nastavené.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>Nastavenie súborových asociácii zlyhalo.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Tímy</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>Naozaj vymazať tento tím?</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>Schémy</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>Nie je možné vymazať východziu schému &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>Naozaj chcete vymazať túto hernú schému?</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>Nie je možné vymazať východziu sadu zbraní &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Nepodarilo sa vytvoriť adresár %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Prezývka</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Prosím, zadajte vašu prezývku</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>Choď!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>východzie</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Spustiť server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Spojiť</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Nastaviť</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Prehrať demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Načítať</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Nastavenie</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pripravený</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Náhodný tím</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Asociovať prípony súborov.</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="obsolete">Nastaviť</translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Názov miestnosti</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Majiteľ</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Pravidlá</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbrane</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Sada zbraní</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Pravdepodobnosti</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Zbrane v krabiciach</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Oneskorenie</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kópia z</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Nie je možné spustiť server: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Nie je možné spustiť engine: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Režím vampíra</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Delostrelectvo</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Režim pevností</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Rozdeliť tímy</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Nezničiteľná zem</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Pridať okraj</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Nízka gravitácia</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Laserové zameriavanie</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Nesmrteľnosť</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Pridať míny</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Náhodné poradie</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Kráľ</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Umiestňovať ježkov</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Klan zdieľa výzbroj</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Vypnúť trámy</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Vypnúť objekty v krajine</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>Režim prežitia umelej inteligencie</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Resetovať zdravie</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Neobmedzené útoky</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Resetovať zbrane</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Individuálne zbrane</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>Vypnúť vietor</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>Viac vetra</translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>hore</translation>
    </message>
    <message>
        <source>left</source>
        <translation>vľavo</translation>
    </message>
    <message>
        <source>right</source>
        <translation>vpravo</translation>
    </message>
    <message>
        <source>down</source>
        <translation>dole</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>útok</translation>
    </message>
    <message>
        <source>put</source>
        <translation>položiť</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>prepnúť</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>nájsť ježka</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>okno výzbroje</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>časovač na 1 sek</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>časovač na 2 sek</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>časovač na 3 sek</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>časovač na 4 sek</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>časovač na 5 sek</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pauza</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>stlmiť hlasitosť</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>zvýšiť hlasitosť</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>zmeniť režim</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>snímať</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>štatistiky
ježkov</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>ukončiť</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>čet</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>história četu</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>potvrdenie</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>presné zameriavanie</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>priblíženie</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>oddialenie</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reštartovať priblíženie</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>dlhý skok</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>vysoký skok</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>slot 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Základné ovládanie</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Ovládanie zbraní</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Ovládanie kurzora a kamery</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Iné</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Presun ježka a mierenie:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Prekoná priepasti a prekážky skokom:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Vypáli vami zvolenú zbraň alebo zapne nástroj:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Položí zbraň alebo vyberie cieľ v mieste pod kurzorom:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Prepne vášho momentálne vybraného ježka (ak je to možné):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Zodvihne zbraň alebo nástroj:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Nastaví časovač na bombách a iných zbraniach s časovou rozbuškou:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Presunie kameru na aktívneho ježka:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Presunie kurzor alebo kameru bez použitia myši:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Zmeniť stupeň priblíženia kamery:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Umožní vám rozhovor s vašim tímom alebo všetkými účastníkmi hry:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pauza, pokračovanie alebo opustenie hry:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Zmena hlasitosti v hre počas hrania:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Prepne celoobrazovkový režim:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Urobí snímok obrazovky:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Prepnúť nápisy nad ježkami:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Os</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Hore)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Dole)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Klobúk</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vľavo)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Vpravo)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Tlačidlo</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Klávesnica</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Myš: Ľavé tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Myš: Prostredné tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Myš: Pravé tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Myš: Kolečko smerom nahor</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Myš: Kolečko smerom nadol</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulátor</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Medzera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Rovná sa</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hore</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Pravý shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Ľavý shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Pravý ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Ľavý ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Pravý alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Ľavý alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Pravý meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Ľavý meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>Tlačidlo A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>Tlačidlo B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>Tlačidlo X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Tlačidlo Y</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>Tlačidlo LB</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>Tlačidlo RB</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Tlačidlo Back</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Tlačidlo Start</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Joystick doľava</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Joystick doprava</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Ľavý prepínač</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Pravý prepínač</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Ľavý joystick (Doprava)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Ľavý joystick (Doľava)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Ľavý joystick (Dole)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Ľavý joystick (Hore)</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Pravý joystick (Dole)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Pravý joystick (Hore)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Pravý joystick (Doprava)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Pravý joystick (Doľava)</translation>
    </message>
</context>
</TS>
